% Calls the function that performs alernating regression on the whole S-System defined in ToyNetwork.m
%
% alternating regression is performed as published in
% Chou I, Martens H, Voit EO: Parameter estimation in biochemical systems models with alternating regression. Theor Biol Med Model 2006, 3:25.
%
% Wolfgang Beyer, 2007

tic

%load the time series data
load TS_noisy.mat

%load the results of performing autosmooth on the time series data
load TS_noisy_AS.mat

%estimated slopes are the ones taken from autosmooth
Si1=result(:,6);
Si2=result(:,7);
Si3=result(:,8);
Si4=result(:,9);

%alternatively one could calculate the true slopes and use them
%uncomment the following lines if you want to use the true slopes

%Si1=[12*TS(:,4).^-.8 - 10*TS(:,2).^.5];
%Si2=[8*TS(:,2).^.5 - 3*TS(:,3).^.75];
%Si3=[3*TS(:,3).^.75 - 5*TS(:,4).^.5.*TS(:,5).^.2];
%Si4=[2*TS(:,2).^.5 - 6*TS(:,5).^.8];

%Set first estimation of degradation term for each equation
bd1=[15; 1];
bd2=[15; 1];
bd3=[15; 1; 1];
bd4=[15; 1];

%Run alternating regression
[Prod, Deg, Error, It] = AR_allX(TS(:,2), TS(:,3), TS(:,4), TS(:,5), Si1, Si2, Si3, Si4, bd1, bd2, bd3, bd4)

%simulate the system with the calculated solution
testSoln=ode45(@ToyNetwork,[0 5],[1.4; 2.7; 1.2; 0.4],[],[Prod(:,2); Deg(:,2)]);
new_t=linspace(0,5,51);
new_x=deval(testSoln,new_t);
calc_t=new_t';
calc_x=new_x';

%simulate the true system
testSoln=ode45(@ToyNetwork,[0 5],[1.4; 2.7; 1.2; 0.4],[],[12 -.8 8 .5 3 .75 2 .5 10 .5 3 .75 5 .5 .2 6 .8]);
new_x=deval(testSoln,new_t);

%plot time courses
plot(calc_t, [calc_x new_x']);
legend('X1','X2','X3','X4','X1true','X2true','X3true','X4true');

%clear unused variables
clear Si1;
clear Si2;
clear Si3;
clear Si4;
clear bd1;
clear bd2;
clear bd3;
clear bd4;
clear calc_x;
clear new_x;
clear testSoln
clear calc_t;
clear new_t;

toc
